Stan Math Library: stan/math/prim/scal/fun/lb_free.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
lb_free.hpp File Reference
`#include <stan/math/prim/scal/fun/identity_free.hpp>`
`#include <stan/math/prim/scal/err/check_greater_or_equal.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <cmath>`
`#include <limits>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , typename TL >
boost::math::tools::promote_args< T, TL >::type | stan::math::lb_free (const T y, const TL lb)
| Return the unconstrained value that produces the specified lower-bound constrained value. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.